# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# NOTE: This file is auto generated by the elixir code generator program.
# Do not edit this file manually.

defmodule GoogleApi.Slides.V1.Model.Shadow do
  @moduledoc """
  The shadow properties of a page element. If these fields are unset, they may be inherited from a parent placeholder if it exists. If there is no parent, the fields will default to the value used for new page elements created in the Slides editor, which may depend on the page element kind.

  ## Attributes

  *   `alignment` (*type:* `String.t`, *default:* `nil`) - The alignment point of the shadow, that sets the origin for translate, scale and skew of the shadow. This property is read-only.
  *   `alpha` (*type:* `number()`, *default:* `nil`) - The alpha of the shadow's color, from 0.0 to 1.0.
  *   `blurRadius` (*type:* `GoogleApi.Slides.V1.Model.Dimension.t`, *default:* `nil`) - The radius of the shadow blur. The larger the radius, the more diffuse the shadow becomes.
  *   `color` (*type:* `GoogleApi.Slides.V1.Model.OpaqueColor.t`, *default:* `nil`) - The shadow color value.
  *   `propertyState` (*type:* `String.t`, *default:* `nil`) - The shadow property state. Updating the shadow on a page element will implicitly update this field to `RENDERED`, unless another value is specified in the same request. To have no shadow on a page element, set this field to `NOT_RENDERED`. In this case, any other shadow fields set in the same request will be ignored.
  *   `rotateWithShape` (*type:* `boolean()`, *default:* `nil`) - Whether the shadow should rotate with the shape. This property is read-only.
  *   `transform` (*type:* `GoogleApi.Slides.V1.Model.AffineTransform.t`, *default:* `nil`) - Transform that encodes the translate, scale, and skew of the shadow, relative to the alignment position.
  *   `type` (*type:* `String.t`, *default:* `nil`) - The type of the shadow. This property is read-only.
  """

  use GoogleApi.Gax.ModelBase

  @type t :: %__MODULE__{
          :alignment => String.t() | nil,
          :alpha => number() | nil,
          :blurRadius => GoogleApi.Slides.V1.Model.Dimension.t() | nil,
          :color => GoogleApi.Slides.V1.Model.OpaqueColor.t() | nil,
          :propertyState => String.t() | nil,
          :rotateWithShape => boolean() | nil,
          :transform => GoogleApi.Slides.V1.Model.AffineTransform.t() | nil,
          :type => String.t() | nil
        }

  field(:alignment)
  field(:alpha)
  field(:blurRadius, as: GoogleApi.Slides.V1.Model.Dimension)
  field(:color, as: GoogleApi.Slides.V1.Model.OpaqueColor)
  field(:propertyState)
  field(:rotateWithShape)
  field(:transform, as: GoogleApi.Slides.V1.Model.AffineTransform)
  field(:type)
end

defimpl Poison.Decoder, for: GoogleApi.Slides.V1.Model.Shadow do
  def decode(value, options) do
    GoogleApi.Slides.V1.Model.Shadow.decode(value, options)
  end
end

defimpl Poison.Encoder, for: GoogleApi.Slides.V1.Model.Shadow do
  def encode(value, options) do
    GoogleApi.Gax.ModelBase.encode(value, options)
  end
end
